# Changelog

## 0.1.1 (2025-08-25)

Full Changelog: [v0.1.0...v0.1.1](https://github.com/fashn-AI/fashn-python-sdk/compare/v0.1.0...v0.1.1)

### Documentation

* **readme:** add companies logo and docs links ([f9d3691](https://github.com/fashn-AI/fashn-python-sdk/commit/f9d36914b08a393c9c574449f044d9709fa74d98))

## 0.1.0 (2025-08-25)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/fashn-AI/fashn-python-sdk/compare/v0.0.1...v0.1.0)

### Features

* **api:** manual updates ([fe3a623](https://github.com/fashn-AI/fashn-python-sdk/commit/fe3a623d72d311534abceced08d840a6ca5314fe))
* **api:** manual updates ([b6a92ae](https://github.com/fashn-AI/fashn-python-sdk/commit/b6a92ae3f706f4ce1b9230883cac47aaec35560f))
* **api:** manual updates ([39f855f](https://github.com/fashn-AI/fashn-python-sdk/commit/39f855fe0bce79fa7b838b1730174e1424843e87))


### Chores

* configure new SDK language ([f7194c0](https://github.com/fashn-AI/fashn-python-sdk/commit/f7194c0976fc9f5656b1152814084af358e06c8e))
* update github action ([5959e35](https://github.com/fashn-AI/fashn-python-sdk/commit/5959e3515f9dbe77776331f33892843cc3cce6eb))
* update SDK settings ([fa39844](https://github.com/fashn-AI/fashn-python-sdk/commit/fa39844915b3dcd00282863b02b2ebff94229eec))
